==> letsnet-services-2.1.26.tgz: package/lib/inner/middlewares.js <==
const checkLogin = require('letsnet-graphed').check

module.exports = function(defaults) {
    let model = {}

    model.loginCheck = function(req, res, next) {
        if(req.session.gLogin == null || req.session.gLogin === undefined) res.redirect('/Login')
        else {
            checkLogin.check({appId: defaults.appId, fingerprint: req.session.gLogin.fingerprint, loggedUser: req.session.gLogin.loggedUser, location: req.session.gLogin.location}, function(error, data) {
                if(error || !data.document.logged_in){
                    req.session.redirectURL = req._parsedOriginalUrl.path
                    res.redirect('/Login')
                }
                else next()
            })
        }
    }

    model.loginCheckJSON = function(req, res, next) {
        if(req.session.gLogin == null || req.session.gLogin === undefined) res.status(200).send({error: true, lCode: '-E1', msg: 'Nincs bejelentkezve!', type:'session-error', func: '@graphedCheckLogin-CHECK'})
        else {
            checkLogin.check({appId: defaults.appId, fingerprint: req.session.gLogin.fingerprint, loggedUser: req.session.gLogin.loggedUser, location: req.session.gLogin.location}, (error, data) => {
                if(error || !data.document.logged_in){
                    res.status(200).send({func: data.func, lCode: "-E1", msg: "Nincs bejelentkezve!", type: "error"})
                }
                else next()
            })
        }
    }

    model.loggedInCheck = function(req, res, next) {
        if(req.session.gLogin == null || req.session.gLogin === undefined) next()
        else {
            checkLogin.check({appId: defaults.appId, fingerprint: req.session.gLogin.fingerprint, loggedUser: req.session.gLogin.loggedUser, location: req.session.gLogin.location}, (error, data) => {
                if(!error){
                    if(data.document.logged_in){
                        let URL = req.session.redirectURL || '/'
                        delete req.session.redirectURL
                        res.redirect(URL)
                    } else next()
                }
                else {
                    delete req.session.gLogin.fingerprint
                    delete req.session.gLogin.logged_user
                    delete req.session.gLogin
                    next()
                }
            })
        }
    }
    return model
}

==> letsnet-services-2.1.28.tgz: package/lib/inner/middlewares.js <==
const checkLogin = require('letsnet-graphed').check

module.exports = function(defaults) {
    let model = {}

    model.loginCheck = function(req, res, next) {
        if(req.session.gLogin == null || req.session.gLogin === undefined) res.redirect('/Login')
        else {
            checkLogin.check({appId: defaults.appId, fingerprint: req.session.gLogin.fingerprint, loggedUser: req.session.gLogin.loggedUser, location: req.session.gLogin.location}, function(data) {
                if(data.type != 'success'  || !data.document.logged_in) {
                    req.session.redirectURL = req._parsedOriginalUrl.path
                    res.redirect('/Login')
                }
                else next()
            })
        }
    }

    model.loginCheckJSON = function(req, res, next) {
        if(req.session.gLogin == null || req.session.gLogin === undefined) res.status(200).send({error: true, lCode: '-E1', msg: 'Nincs bejelentkezve!', type:'session-error', func: '@graphedCheckLogin-CHECK'})
        else {
            checkLogin.check({appId: defaults.appId, fingerprint: req.session.gLogin.fingerprint, loggedUser: req.session.gLogin.loggedUser, location: req.session.gLogin.location}, (data) => {
                if(data.type != 'success' || !data.document.logged_in){
                    res.status(200).send({func: data.func, lCode: "-E1", msg: "Nincs bejelentkezve!", type: "error"})
                }
                else next()
            })
        }
    }

    model.loggedInCheck = function(req, res, next) {
        if(req.session.gLogin == null || req.session.gLogin === undefined) next()
        else {
            checkLogin.check({appId: defaults.appId, fingerprint: req.session.gLogin.fingerprint, loggedUser: req.session.gLogin.loggedUser, location: req.session.gLogin.location}, (data) => {
                if(data.type == 'success'){
                    if(data.document.logged_in){
                        let URL = req.session.redirectURL || '/'
                        delete req.session.redirectURL
                        res.redirect(URL)
                    } else next()
                }
                else {
                    delete req.session.gLogin.fingerprint
                    delete req.session.gLogin.logged_user
                    delete req.session.gLogin
                    next()
                }
            })
        }
    }
    return model
}
